caretTop property

Offset? get caretTop

The offset of the top of the caret, or null if no caret should be displayed.

When the caret is drawn, the caret will have a thickness. That width should be placed either on the left or right of this offset, based on whether the caretAffinity is upstream or downstream, respectively.

Implementation

Offset? get caretTop => _caretTop;