CommandTransaction class
Constructors
-
CommandTransaction(List<
EditCommand> commands, DateTime firstChangeTime)
Properties
-
changes
→ List<
EditEvent> -
final
-
commands
→ List<
EditCommand> -
final
- firstChangeTime → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastChangeTime ↔ DateTime
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited