ContentLayerWidget class abstract

A widget that can be displayed as a layer in a ContentLayers widget.

ContentLayers uses a special type of layer widget to avoid timing issues with Flutter's build order. This timing issue is only a concern when a layer widget inspects content layout within ContentLayers. However, to prevent developer confusion and mistakes, all layer widgets are forced to be ContentLayerWidgets.

Extend ContentLayerStatefulWidget to create a layer that's based on the content layout within the ancestor ContentLayers, and requires mutable state.

Extend ContentLayerStatelessWidget to create a layer that's based on the content layout within the ancestor ContentLayers, but doesn't require mutable state.

To quickly and easily build a layer from a traditional widget tree, create a ContentLayerProxyWidget with the desired subtree. This approach is a quicker and more convenient alternative to ContentLayerStatelessWidget for the simplest of layer trees.

Implemented types
Implementers

Constructors

ContentLayerWidget()

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited