DebugPaintConfig class

Configures the aspects of a document that show debug paint.

Constructors

DebugPaintConfig({bool scrolling = false, bool gestures = false, String? scrollingMinimapId, bool layout = false})
const

Properties

gestures → bool
final
hashCode → int
The hash code for this object.
no setterinherited
layout → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrolling → bool
final
scrollingMinimapId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited