DeleteSelectionRequest class

Deletes the selected content within the document.

Any selected, non-deletable nodes are retained without removal.

The affinity defines the direction to where the user is trying to delete. For example, if the users presses the backspace key, the affinity should be TextAffinity.upstream. If the user presses the delete key, the affinity should be TextAffinity.downstream. The affinity influences the new selection after the deletion when the dowstream of upstream node is non-deletable. For example, pressing backspace when the upstream node is not deletable doesn't change the selection, but pressing delete does.

Implemented types

Constructors

DeleteSelectionRequest(TextAffinity affinity)
const

Properties

affinity TextAffinity
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited