getDesiredCursorAtOffset abstract method
Returns the desired MouseCursor at the given (x,y) localOffset, or
null if this component has no preference for the cursor style.
Implementation
MouseCursor? getDesiredCursorAtOffset(Offset localOffset);
Returns the desired MouseCursor at the given (x,y) localOffset, or
null if this component has no preference for the cursor style.
MouseCursor? getDesiredCursorAtOffset(Offset localOffset);