movePositionLeft abstract method

NodePosition? movePositionLeft(
  1. NodePosition currentPosition, [
  2. MovementModifier? movementModifier
])

Returns a new position within this component's node that corresponds to the currentPosition moved left one unit, as interpreted by this component/node, in conjunction with any relevant movementModifier.

The structure and options for movementModifier is determined by each component/node combination.

Returns null if the concept of horizontal movement does not make sense for this component.

Returns null if there is nowhere to move left within this component, such as when the currentPosition is the first character within a paragraph.

Implementation

NodePosition? movePositionLeft(NodePosition currentPosition, [MovementModifier? movementModifier]);