getEdgeForPosition abstract method

Rect? getEdgeForPosition(
  1. DocumentPosition position
)

Returns the upstream edge or downstream edge of the content at the given position.

The edge is defined by a zero-width Rect whose offset and height is determined by the offset and height of the content at the given position.

The edge of a piece of content is helpful for sizing and positioning a caret.

Implementation

Rect? getEdgeForPosition(DocumentPosition position);