DocumentNode class abstract
A single content node within a Document.
- Implementers
- Available extensions
- Annotations
Constructors
-
DocumentNode({Map<
String, dynamic> ? metadata})
Properties
- asListItem → ListItemNode
-
Available on DocumentNode, provided by the ListItemNodeType extension
no setter - asTask → TaskNode
-
Available on DocumentNode, provided by the TaskNodeType extension
no setter - asTextNode → TextNode
-
Available on DocumentNode, provided by the TextNodeExtensions extension
no setter - beginningPosition → NodePosition
-
Returns the NodePosition that corresponds to the beginning
of content in this node.
no setter
- endPosition → NodePosition
-
Returns the NodePosition that corresponds to the end of the
content in this node.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
ID that is unique within a Document.
no setter
- isDeletable → bool
-
no setter
-
metadata
→ Map<
String, dynamic> -
Returns all metadata attached to this DocumentNode.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeSelection(
{required NodePosition base, required NodePosition extent}) → NodeSelection -
Returns a node-specific representation of a selection from
basetoextent. -
containsPosition(
Object position) → bool -
Returns
trueif this DocumentNode contains the givenposition, orfalseif thepositiondoesn't sit within this node, or if thepositiontype doesn't apply to this DocumentNode. -
copyAndReplaceMetadata(
Map< String, dynamic> newMetadata) → DocumentNode -
Returns a copy of this DocumentNode, replacing its existing
metadata with
newMetadata. -
copyContent(
NodeSelection selection) → String? -
Returns a plain-text version of the content in this node
within
selection, or null if the given selection does not make sense as plain-text. -
copyMetadata(
) → Map< String, dynamic> - Returns a copy of this node's metadata.
-
copyWithAddedMetadata(
Map< String, dynamic> newProperties) → DocumentNode -
Returns a copy of this DocumentNode with
newPropertiesadded to the node's metadata. -
getAffinityBetween(
{required NodePosition base, required NodePosition extent}) → TextAffinity -
Available on DocumentNode, provided by the InspectNodeAffinity extension
Returns the affinity direction implied by the givenbaseandextent. -
getMetadataValue(
String key) → dynamic -
Returns this node's metadata value for the given
key. -
hasEquivalentContent(
DocumentNode other) → bool -
Returns true if the
othernode is the same type as this node, and contains the same content. -
hasMetadataValue(
String key) → bool -
Returns
trueif this node has a non-null metadata value for the given metadatakey, and returnsfalse, otherwise. -
initAddToMetadata(
Map< String, dynamic> addedMetadata) → void -
Adds
addedMetadatato this nodes metadata. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectDownstreamPosition(
NodePosition position1, NodePosition position2) → NodePosition -
Inspects
position1andposition2and returns the one that's positioned further downstream in this DocumentNode. -
selectUpstreamPosition(
NodePosition position1, NodePosition position2) → NodePosition -
Inspects
position1andposition2and returns the one that's positioned further upstream in this DocumentNode. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override