copyWithAddedMetadata abstract method

DocumentNode copyWithAddedMetadata(
  1. Map<String, dynamic> newProperties
)

Returns a copy of this DocumentNode with newProperties added to the node's metadata.

If newProperties contains keys that already exist in this node's metadata, the existing properties are overwritten by newProperties.

Implementation

DocumentNode copyWithAddedMetadata(Map<String, dynamic> newProperties);