isPositionCloserToEnd method
Returns true if the given position is closer to the end of this node's
content than it is to the end.
Implementation
bool isPositionCloserToEnd(NodePosition position) => !isPositionCloserToStart(position);
Returns true if the given position is closer to the end of this node's
content than it is to the end.
bool isPositionCloserToEnd(NodePosition position) => !isPositionCloserToStart(position);