DocumentScroller class

Scrolling status and controls for a document experience.

Depending on the surrounding widget tree, a DocumentScroller might be attached to a descendant Scrollable, which was added by the document experience widget (like SuperEditor or SuperReader). Or, a DocumentScroller might be attached to an ancestor Scrollable, if the document experience chooses to use an ancestor Scrollable.

Implementers

Constructors

DocumentScroller()

Properties

hashCode int
The hash code for this object.
no setterinherited
maxScrollExtent double
The maximum possible scrolling offset, at which point the end of the scrolling content is visible in the viewport.
no setter
minScrollExtent double
The smallest possible scrolling offset, which is usually zero.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollOffset double
The current scroll offset in the viewport, which is represented by the number of pixels between the top-left corner of the viewport, and the top-left corner of the content that sits inside the viewport.
no setter
viewportDimension double
The height of a vertically scrolling viewport, or the width of a horizontally scrolling viewport.
no setter

Methods

addScrollChangeListener(VoidCallback listener) → void
animateTo(double to, {required Duration duration, Curve curve = Curves.easeInOut}) → void
Animates scrollOffset from its current offset to to, over the given duration of time, following the given animation curve.
attach(ScrollPosition scrollPosition) → void
detach() → void
dispose() → void
jumpBy(double delta) → void
Immediately moves the scrollOffset by delta pixels.
jumpTo(double newScrollOffset) → void
Immediately moves the scrollOffset to newScrollOffset.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeScrollChangeListener(VoidCallback listener) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited