FloatingCursorPolicies class

Values that reflect standard or default floating cursor policies.

Constructors

FloatingCursorPolicies()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultFloatingCursorHeight → const double
defaultFloatingCursorWidth → const double
maximumDistanceToBeNearText → const double
The maximum horizontal distance from the bounds of selectable text, for which we want to render the floating cursor.