FunctionalEditReaction class

An EditReaction that delegates its reaction to a given callback function.

Inheritance

Constructors

FunctionalEditReaction({Reaction? modifyContent, Reaction? react})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

modifyContent(EditContext editorContext, RequestDispatcher requestDispatcher, List<EditEvent> changeList) → void
Executes additional modifications within the current editor transaction.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
react(EditContext editorContext, RequestDispatcher requestDispatcher, List<EditEvent> changeList) → void
Executes additional actions in a new standalone transaction.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited