FunctionalSuperEditorLayerBuilder class
A SuperEditorLayerBuilder that's implemented with a given function, so that simple use-cases don't need to sub-class SuperEditorLayerBuilder.
- Implemented types
Constructors
- FunctionalSuperEditorLayerBuilder(ContentLayerWidget _delegate(BuildContext context, SuperEditorContext editContext))
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context, SuperEditorContext editContext) → ContentLayerWidget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited