focusNode property
FocusNode for the text field that contains this IOSTextFieldInteractor.
IOSTextFieldInteractor only shows editing controls, and listens for drag
events when focusNode has focus.
IOSTextFieldInteractor requests focus when the user taps on it.
Implementation
final FocusNode focusNode;