InlineWidgetBuilder typedef

InlineWidgetBuilder = Widget? Function(BuildContext context, TextStyle textStyle, Object placeholder)

Builder that returns a Widget for a given placeholder, or null if this builder doesn't know how to build the given placeholder.

The given textStyle is the style applied to the text in the vicinity of the placeholder.

Implementation

typedef InlineWidgetBuilder = Widget? Function(
  BuildContext context,
  TextStyle textStyle,
  Object placeholder,
);