ItemSelectionList<T> class

A list where the user can navigate between its items and select one of them.

Includes the following keyboard selection behaviors:

  • Pressing UP/DOWN moves the "active" item selection up/down.
  • Pressing UP with the first item active moves the active item selection to the last item.
  • Pressing DOWN with the last item active moves the active item selection to the first item.
  • Pressing ENTER selects the currently active item.
Inheritance

Constructors

ItemSelectionList({Key? key, required T? value, required List<T> items, Axis axis = Axis.vertical, required SelectableListItemBuilder<T> itemBuilder, IndexedWidgetBuilder? separatorBuilder, ValueChanged<T?>? onItemActivated, required ValueChanged<T?> onItemSelected, VoidCallback? onCancel, FocusNode? focusNode})
const

Properties

axis Axis
Determines if the list should be displayed vertically or horizontally.
final
focusNode FocusNode?
The FocusNode of the list.
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder SelectableListItemBuilder<T>
Builds each item in the popover list.
final
items List<T>
The items that will be displayed in the popover list.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancel VoidCallback?
Called when the user presses ESCAPE.
final
onItemActivated ValueChanged<T?>?
Called when the user activates an item on the popover list.
final
onItemSelected ValueChanged<T?>
Called when the user selects an item on the popover list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separatorBuilder IndexedWidgetBuilder?
Builds a separator for each item in the list.
final
value → T?
The currently selected value or null if no item is selected.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ItemSelectionList<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited