KeyboardPanelController<PanelType> class

Shows and hides the keyboard panel and software keyboard.

Constructors

KeyboardPanelController(SoftwareKeyboardController softwareKeyboardController)

Properties

debugBestGuessKeyboardHeight ValueNotifier<double?>
The height that we believe the keyboard occupies.
final
hasDelegate bool
Whether this controller is currently attached to a delegate that knows how to show a toolbar, and open/close the software keyboard and keyboard panel.
no setter
hashCode int
The hash code for this object.
no setterinherited
isKeyboardPanelOpen bool
Whether the delegate currently wants a keyboard panel to be open.
no setter
isSoftwareKeyboardOpen bool
Whether the delegate currently wants a keyboard panel to be open.
no setter
openPanel → PanelType?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softwareKeyboardController SoftwareKeyboardController
final
toolbarVisibility KeyboardToolbarVisibility
Whether the toolbar should be displayed, anchored to the top of the keyboard area.
getter/setter pair

Methods

attach(KeyboardPanelScaffoldDelegate<PanelType> delegate) → void
Attaches this controller to a delegate that knows how to show a toolbar, open and close the software keyboard, and the keyboard panel.
closeKeyboardAndPanel() → void
Closes the software keyboard if it's open, or closes the keyboard panel if it's open, and fully closes the keyboard (IME) connection.
detach() → void
Detaches this controller from its delegate.
dispose() → void
hideKeyboardPanel() → void
Hides the keyboard panel, if it's open.
hideSoftwareKeyboard() → void
Hides (doesn't close) the software keyboard, if it's open.
hideToolbar() → void
Hides the toolbar that's mounted to the top of the keyboard area.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showKeyboardPanel(PanelType panel) → void
Shows the keyboard panel, if it's closed, and hides (doesn't close) the software keyboard, if it's open.
showSoftwareKeyboard() → void
Shows the software keyboard, if it's hidden.
showToolbar() → void
Shows the toolbar that's mounted to the top of the keyboard area.
toggleToolbar() → void
Shows the toolbar, if it's hidden, or hides the toolbar, if it's visible.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited