MacOsSelectors class

MacOS selector names that are sent to TextInputClient.performSelector.

These selectors express the user intent and are generated by shortcuts. For example, pressing SHIFT + Left Arrow key generates a moveLeftAndModifySelection selector.

The full list can be found on https://developer.apple.com/documentation/appkit/nsstandardkeybindingresponding?changes=_8&language=objc

Constructors

MacOsSelectors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cancelOperation → const String
deleteBackward → const String
deleteBackwardByDecomposingPreviousCharacter → const String
deleteForward → const String
deleteToBeginningOfLine → const String
deleteToEndOfLine → const String
deleteWordBackward → const String
deleteWordForward → const String
insertBacktab → const String
insertNewLine → const String
insertTab → const String
moveBackward → const String
moveDown → const String
moveDownAndModifySelection → const String
moveForward → const String
moveLeft → const String
moveLeftAndModifySelection → const String
moveParagraphBackwardAndModifySelection → const String
moveParagraphForwardAndModifySelection → const String
moveRight → const String
moveRightAndModifySelection → const String
moveToBeginningOfDocument → const String
moveToBeginningOfDocumentAndModifySelection → const String
moveToBeginningOfParagraph → const String
moveToEndOfDocument → const String
moveToEndOfDocumentAndModifySelection → const String
moveToEndOfParagraph → const String
moveToLeftEndOfLine → const String
moveToLeftEndOfLineAndModifySelection → const String
moveToRightEndOfLine → const String
moveToRightEndOfLineAndModifySelection → const String
moveUp → const String
moveUpAndModifySelection → const String
moveWordLeft → const String
moveWordLeftAndModifySelection → const String
moveWordRight → const String
moveWordRightAndModifySelection → const String
pageDownAndModifySelection → const String
pageUpAndModifySelection → const String
scrollPageDown → const String
scrollPageUp → const String
scrollToBeginningOfDocument → const String
scrollToEndOfDocument → const String
transpose → const String