MagnifierAndToolbarController class

Controls the display and position of a magnifier and a floating toolbar.

Mixed-in types

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isToolbarPositioned bool
Whether the toolbar currently has a designated display position.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenPadding EdgeInsets?
Minimum space from the screen edges.
getter/setter pair
shouldDisplayMagnifier bool
Whether the magnifier should be displayed.
no setter
shouldDisplayToolbar bool
Whether the toolbar should be displayed.
no setter
toolbarBottomAnchor Offset?
The point about which the floating toolbar should focus, when the toolbar appears below the selected content.
no setter
toolbarTopAnchor Offset?
The point about which the floating toolbar should focus, when the toolbar appears above the selected content.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
hideMagnifier() → void
Hides the magnifier.
hideToolbar() → void
Hides the toolbar.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
positionToolbar({required Offset topAnchor, required Offset bottomAnchor}) → void
Sets the toolbar's position to the given topAnchor and bottomAnchor.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
showMagnifier() → void
Shows the magnify, and hides the toolbar.
showToolbar() → void
Shows the toolbar, and hides the magnifier.
toggleToolbar() → void
Toggles the toolbar from visible to not visible, or vis-a-versa.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited