MarkdownSyntax enum

Inheritance
Available extensions

Values

normal → const MarkdownSyntax

Standard markdown syntax.

superEditor → const MarkdownSyntax

Extended syntax which supports serialization of text alignment, strikethrough, underline and image size.

Underline text is serialized between a pair of ¬.

Text alignment is serialized using an alignment notation at the line preceding the paragraph:

:--- represents left alignment. (The default)

:---: represents center alignment.

---: represents right alignment.

-::- represents justify alignment.

Image size is serialized using the notation =widthxheight after the url, separated by a space.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MarkdownSyntax>
A constant List of the values in this enum, in order of their declaration.