MarkdownTableViewModel class

View model that configures the appearance of a MarkdownTableComponent.

View models move through various style phases, which fill out various properties in the view model. For example, one phase applies all StyleRules, and another phase configures content selection and caret appearance.

Inheritance
Mixed-in types

Constructors

MarkdownTableViewModel({required String nodeId, required DateTime? createdAt, double? maxWidth, required EdgeInsetsGeometry padding, double opacity = 1.0, required List<List<MarkdownTableCellViewModel>> cells, TableBorder? border, TableColumnWidth columnWidth = const IntrinsicColumnWidth(), TableComponentFit fit = TableComponentFit.scale, InlineWidgetBuilderChain inlineWidgetBuilders = const [], required Color caretColor, DocumentNodeSelection<NodeSelection>? selection, Color selectionColor = Colors.transparent})

Properties

border TableBorder?
The border to draw around the table and its cells.
getter/setter pair
caretColor Color
The color to use when painting the caret.
getter/setter pair
cells List<List<MarkdownTableCellViewModel>>
The cells of the table, indexed as [rowIndex][columnIndex].
final
columnWidth TableColumnWidth
The policy that sizes the width of each column in the table.
getter/setter pair
createdAt DateTime?
When view model's corresponding node was created, which can be used for making decisions about animated invalidations.
getter/setter pairinherited
fit TableComponentFit
How the table responds when it wants to be wider than the available width.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
inlineWidgetBuilders InlineWidgetBuilderChain
A chain of builders that create inline widgets that can be embedded inside the table's cells.
getter/setter pair
maxWidth double?
The maximum width of this component in the layout, or null to defer to the layout's preference.
getter/setter pairinherited
nodeId String
finalinherited
opacity double
The opacity of this whole node.
getter/setter pairinherited
padding EdgeInsetsGeometry
The padding applied around this component.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection DocumentNodeSelection<NodeSelection>?
The selection within the node represented by this view model.
getter/setter pairinherited
selectionColor Color
The color to be applied to the selection.
getter/setter pairinherited

Methods

applyStyles(Map<String, dynamic> styles) → void
override
copy() SingleColumnLayoutComponentViewModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override