inlineWidgetBuilders property
A chain of builders that create inline widgets that can be embedded inside the table's cells.
Implementation
InlineWidgetBuilderChain inlineWidgetBuilders;
A chain of builders that create inline widgets that can be embedded inside the table's cells.
InlineWidgetBuilderChain inlineWidgetBuilders;