OrderedListNumeralStyle enum
The styling of an ordered list numberal.
Values
- arabic → const OrderedListNumeralStyle
-
Arabic numeral style (e.g. 1, 2, 3, ...).
- lowerAlpha → const OrderedListNumeralStyle
-
Lowercase alphabetic numeral style (e.g. a, b, c, ...).
- upperAlpha → const OrderedListNumeralStyle
-
Uppercase alphabetic numeral style (e.g. A, B, C, ...).
- lowerRoman → const OrderedListNumeralStyle
-
Lowercase Roman numeral style (e.g. i, ii, iii, ...).
- upperRoman → const OrderedListNumeralStyle
-
Uppercase Roman numeral style (e.g. I, II, III, ...).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OrderedListNumeralStyle> - A constant List of the values in this enum, in order of their declaration.