SingleAxisTrackpadAndWheelScroller class

A widget that scrolls a given controller, either vertically or horizontally, when the user interacts with the widget via a trackpad or a mouse wheel, but only when no other scrollable has claimed scrolling ownership.

Integrating trackpad and mouse wheel scrolling is a challenge because those pointer and scrolling events don't participate in the gesture arena. Therefore, you have to implement scrolling ownership yourself.

This widget participates in a custom scrolling ownership behavior. This widget talks to a GlobalScrollLock. The global scroll lock assigns scrolling ownership based on whether a given pointer event is mostly vertical, or mostly horizontal. This way, you can use a trackpad or a Magic Mouse to scroll something like a chat conversation vertically, while also scrolling a table horizontally, without scrolling both at the same time.

This scroll ownership system is very basic, but it should be sufficient for common use-cases.

Inheritance

Constructors

SingleAxisTrackpadAndWheelScroller({Key? key, required Axis axis, required ScrollController controller, required Widget child})
const

Properties

axis Axis
final
child Widget
final
controller ScrollController
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SingleAxisTrackpadAndWheelScroller>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited