SingleColumnLayoutComponentViewModel class abstract

Base class for a component view model that appears within a SingleColumnDocumentLayout.

Implementers

Constructors

SingleColumnLayoutComponentViewModel({required String nodeId, required DateTime? createdAt, double? maxWidth, required EdgeInsetsGeometry padding, double opacity = 1.0})

Properties

createdAt DateTime?
When view model's corresponding node was created, which can be used for making decisions about animated invalidations.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
maxWidth double?
The maximum width of this component in the layout, or null to defer to the layout's preference.
getter/setter pair
nodeId String
final
opacity double
The opacity of this whole node.
getter/setter pair
padding EdgeInsetsGeometry
The padding applied around this component.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyStyles(Map<String, dynamic> styles) → void
copy() SingleColumnLayoutComponentViewModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override