SoftwareKeyboardControllerDelegate class abstract

Delegate that's attached to a SoftwareKeyboardController, which implements the opening and closing of the software keyboard.

Properties

hashCode int
The hash code for this object.
no setterinherited
isConnectedToIme bool
Whether this delegate is currently connected to the platform IME.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the software keyboard, and the IME connection.
hide() → void
Hides the software keyboard without closing the IME connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({required int viewId}) → void
Opens the software keyboard.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited