isConnectedToIme property
bool
get
isConnectedToIme
Whether this delegate is currently connected to the platform IME.
Implementation
bool get isConnectedToIme;
Whether this delegate is currently connected to the platform IME.
bool get isConnectedToIme;