documentLayoutKey property
GlobalKey that's bound to the DocumentLayout within
this SuperEditor.
This key can be used to lookup visual components in the document
layout within this SuperEditor.
Implementation
final GlobalKey? documentLayoutKey;
GlobalKey that's bound to the DocumentLayout within
this SuperEditor.
This key can be used to lookup visual components in the document
layout within this SuperEditor.
final GlobalKey? documentLayoutKey;