SuperEditorAndroidControlsOverlayManager class

Adds and removes an Android-style editor controls overlay, as dictated by an ancestor SuperEditorAndroidControlsScope.

Inheritance

Constructors

SuperEditorAndroidControlsOverlayManager({Key? key, String? tapRegionGroupId, required Document document, required DocumentLayoutResolver getDocumentLayout, required ValueListenable<DocumentSelection?> selection, required void setSelection(DocumentSelection?), required ValueListenable<bool> isImeConnected, required SignalNotifier scrollChangeSignal, required ValueListenable<DragHandleAutoScroller?> dragHandleAutoScroller, DocumentFloatingToolbarBuilder? defaultToolbarBuilder, bool showDebugPaint = false, Widget? child})
const

Properties

child Widget?
final
defaultToolbarBuilder DocumentFloatingToolbarBuilder?
final
document Document
final
dragHandleAutoScroller ValueListenable<DragHandleAutoScroller?>
final
getDocumentLayout DocumentLayoutResolver
final
hashCode int
The hash code for this object.
no setterinherited
isImeConnected ValueListenable<bool>
A listenable that reports whether the IME is currently connected to this editor, which means either a software keyboard or hardware keyboard is currently configured to edit the document in this editor.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollChangeSignal SignalNotifier
final
selection ValueListenable<DocumentSelection?>
final
setSelection → void Function(DocumentSelection?)
final
showDebugPaint bool
Paints some extra visual ornamentation to help with debugging, when true.
final
tapRegionGroupId String?
A group ID for a tap region that surrounds the editor and also surrounds any related widgets, such as drag handles and a toolbar.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SuperEditorAndroidControlsOverlayManager>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited