isImeConnected property
A listenable that reports whether the IME is currently connected to this editor, which means either a software keyboard or hardware keyboard is currently configured to edit the document in this editor.
This signal is used to, for example, to decide whether we should show the popover toolbar on tap.
Implementation
final ValueListenable<bool> isImeConnected;