contentTapHandlers property

List<ContentTapDelegate> get contentTapHandlers

Optional handlers that respond to taps on content, e.g., opening a link when the user taps on text with a link attribution.

If a handler returns TapHandlingInstruction.halt, no subsequent handlers nor the default tap behavior will be executed.

Implementation

List<ContentTapDelegate> get contentTapHandlers => const [];