SuperTextFieldTapHandler class abstract

Tap handler that can (optionally) respond to single, double, and triple taps, as well as dictate the cursor appearance on desktop.

Implementers

Constructors

SuperTextFieldTapHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Operators

operator ==(Object other) bool
The equality operator.
inherited