setStyle method

  1. @override
void setStyle({
  1. required String? fontFamily,
  2. required double? fontSize,
  3. required FontWeight? fontWeight,
  4. required TextDirection textDirection,
  5. required TextAlign textAlign,
})
override

Send text styling information.

This information is used by the Flutter Web Engine to change the style of the hidden native input's content. Hence, the content size will match to the size of the editable widget's content.

Implementation

@override
void setStyle(
        {required String? fontFamily,
        required double? fontSize,
        required FontWeight? fontWeight,
        required TextDirection textDirection,
        required TextAlign textAlign}) =>
    client?.setStyle(
        fontFamily: fontFamily,
        fontSize: fontSize,
        fontWeight: fontWeight,
        textDirection: textDirection,
        textAlign: textAlign);