UnderlineSyntax class
A Markdown DelimiterSyntax that matches underline spans of text, which are represented in
Markdown with surrounding ¬ tags, e.g., "this is ¬underline¬ text".
This DelimiterSyntax produces Elements with a u tag.
Constructors
Properties
- allowIntraWord → bool
-
Whether to allow intra-word delimiter runs. CommonMark emphasis and
strong emphasis does not allow this, but GitHub-Flavored Markdown allows
it on strikethrough.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- pattern → RegExp
-
finalinherited
- requiresDelimiterRun → bool
-
Whether this is parsed according to the same nesting rules as emphasis
delimiters.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
finalinherited
Methods
-
close(
InlineParser parser, Delimiter opener, Delimiter closer, {required List< Node> getChildren(), required String tag}) → Iterable<Node> ? - Attempts to close this tag at the current position.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMatch(
InlineParser parser, Match match) → bool -
Processes
match, adding nodes toparserand possibly advancingparser.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
tryMatch(
InlineParser parser, [int? startMatchPos]) → bool -
Tries to match at the parser's current position.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited