close method
Attempts to close this tag at the current position.
If a tag cannot be closed at the current position (for example, if a link
reference cannot be found for a link tag's label), then null is
returned.
If a tag can be closed at the current position, then this method calls
getChildren, in which parser parses any nested text into child nodes.
The returned Iterable includes these children nodes.
Implementation
@override
Iterable<md.Node>? close(
md.InlineParser parser,
md.Delimiter opener,
md.Delimiter closer, {
required List<md.Node> Function() getChildren,
required String tag,
}) {
final element = md.Element('u', getChildren());
return [element];
}