AttributedTextEditingController class
- Mixed-in types
-
- Implementers
Methods
-
addComposingAttributions(Set<Attribution> attributions)
→ void
-
Adds the given
attributions to composingAttributions.
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
buildTextSpan(AttributionStyleBuilder styleBuilder)
→ TextSpan
-
-
clear()
→ void
-
Clears the text, selection, composing attributions, and composing region.
-
clearComposingAttributions()
→ void
-
Removes all attributions from composingAttributions.
-
clearSelectionAttributions()
→ void
-
Removes all attributions from the text that is currently selected.
-
clearText()
→ void
-
Clears the text, composing attributions, composing region, and moves
the collapsed selection to the start of the now empty text controller.
-
clearTextAndSelection()
→ void
-
Clears the text, selection, composing attributions, and composing region.
-
copySelectedTextToClipboard()
→ void
-
-
delete({required int from, required int to, TextSelection? newSelection, TextRange? newComposingRegion})
→ void
-
Removes the text between
from (inclusive) and to (exclusive).
-
deleteCharacter(TextAffinity direction)
→ void
-
-
deleteNextCharacter({TextRange? newComposingRegion})
→ void
-
Deletes the character after the currently collapsed selection.
-
deletePreviousCharacter({TextRange? newComposingRegion})
→ void
-
Deletes the character before the currently collapsed selection and
moves selection upstream by one character.
-
deleteSelectedText()
→ void
-
-
deleteSelection({TextRange? newComposingRegion})
→ void
-
Deletes the text within the current selection.
-
deleteTextOnLineAfterCaret({required ProseTextLayout textLayout})
→ void
-
-
deleteTextOnLineBeforeCaret({required ProseTextLayout textLayout})
→ void
-
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
insert({required AttributedText newText, required int insertIndex, TextSelection? newSelection, TextRange? newComposingRegion})
→ void
-
Inserts
newText, starting at the given insertIndex.
-
insertAtCaret({required String text, TextRange? newComposingRegion})
→ void
-
Inserts the given
text at the current caret position.
-
insertAtCaretUnstyled({required String text, TextRange? newComposingRegion})
→ void
-
Inserts the given
text at the current caret position without any
attributions applied to the text.
-
insertAtCaretWithUpstreamAttributions({required String text, TextRange? newComposingRegion})
→ void
-
Inserts the given
text at the current caret position, extending whatever
attributions exist at the offset before the insertion.
-
insertAttributedTextAtCaret({required AttributedText attributedText, TextRange? newComposingRegion})
→ void
-
Inserts the given
attributedText at the current caret position.
-
insertCharacter(String character)
→ void
-
-
insertNewline()
→ void
-
-
isSelectionWithinTextBounds(TextSelection selection)
→ bool
-
-
moveCaretHorizontally({required ProseTextLayout textLayout, required bool expandSelection, required bool moveLeft, required MovementModifier? movementModifier})
→ void
-
-
moveCaretVertically({required ProseTextLayout textLayout, required bool expandSelection, required bool moveUp})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
pasteClipboard()
→ Future<void>
-
-
removeComposingAttributions(Set<Attribution> attributions)
→ void
-
Removes the given
attributions from composingAttributions.
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
replace({required AttributedText newText, required int from, required int to, TextSelection? newSelection, TextRange? newComposingRegion})
→ void
-
Removes the text between
from (inclusive) and to (exclusive), and replaces that
text with newText.
-
replaceSelectionWithAttributedText({required AttributedText attributedReplacementText, TextRange? newComposingRegion})
→ void
-
Replaces the currently selected text with
attributedReplacementText and
collapses the selection at the end of attributedReplacementText.
-
replaceSelectionWithTextAndUpstreamAttributions({required String replacementText, TextRange? newComposingRegion})
→ void
-
Replaces the currently selected text with
replacementText and collapses
the selection at the end of replacementText.
-
replaceSelectionWithUnstyledText({required String replacementText, TextRange? newComposingRegion})
→ void
-
Replaces the currently selected text with un-styled text and collapses
the selection at the end of the text.
-
selectAll()
→ void
-
-
toggleComposingAttributions(Set<Attribution> attributions)
→ void
-
Toggles the presence of each of the given
attributions within
the composingAttributions.
-
toggleSelectionAttributions(List<Attribution> attributions)
→ void
-
Toggles the presence of each of the given
attributions within
the text in the selection.
-
toString()
→ String
-
A string representation of this object.
inherited
-
update({AttributedText? text, TextSelection? selection, TextRange? composingRegion})
→ void
-
-
updateTextAndSelection({required AttributedText text, required TextSelection selection})
→ void
-