ComposingRegionChangeEvent class
A EditEvent that represents a change to the user's composing region within a document.
Constructors
- ComposingRegionChangeEvent({required DocumentRange? oldComposingRegion, required DocumentRange? newComposingRegion})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newComposingRegion → DocumentRange?
-
final
- oldComposingRegion → DocumentRange?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
describe(
) → String -
Describes this change in a human-readable way.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited