CustomUnderline class
Data structure, which describes a type of underline, which should be painted across the given textRange.
A CustomUnderline applies to a given piece of text - it does not encode any particular document node/position.
Constructors
- CustomUnderline(String type, TextRange textRange)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textRange → TextRange
-
The range of text within some text block to which this underline applies.
final
- type → String
-
A name that represents the type of underline, which maps to some painting
style, e.g., "straight", "squiggle".
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited