history property
List<CommandTransaction>
get
history
A list of editor transactions that were run previously, leading to the current state of the document, and other editables.
Implementation
List<CommandTransaction> get history => List.from(_history);