FunctionalDeltaSerializer class
A DeltaSerializer that forwards to a given delegate function.
- Implemented types
Constructors
- FunctionalDeltaSerializer(DeltaSerializerDelegate _delegate)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
DocumentNode node, Delta deltas) → bool -
Tries to serialize the given DocumentNode into the given
deltas, returningtrueif this serializer was able to serialize thenode, orfalseif this serializer wasn't made to serialize this kind ofnode.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited