MarkdownTableCellViewModel class
View model that configures the appearance of a MarkdownTableComponent's cell.
- Inheritance
-
- Object
- SingleColumnLayoutComponentViewModel
- MarkdownTableCellViewModel
Constructors
-
MarkdownTableCellViewModel({required String nodeId, required AttributedText text, TextAlign textAlign = TextAlign.left, AttributionStyleBuilder textStyleBuilder = noStyleBuilder, required EdgeInsetsGeometry padding, BoxDecoration? decoration, required Map<
String, dynamic> metadata, required DateTime? createdAt})
Properties
- createdAt ↔ DateTime?
-
When view model's corresponding node was created, which can be used for
making decisions about animated invalidations.
getter/setter pairinherited
- decoration ↔ BoxDecoration?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxWidth ↔ double?
-
The maximum width of this component in the layout, or
nullto defer to the layout's preference.getter/setter pairinherited -
metadata
↔ Map<
String, dynamic> -
getter/setter pair
- nodeId → String
-
finalinherited
- opacity ↔ double
-
The opacity of this whole node.
getter/setter pairinherited
- padding ↔ EdgeInsetsGeometry
-
The padding applied around this component.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → AttributedText
-
final
- textAlign ↔ TextAlign
-
getter/setter pair
- textStyleBuilder ↔ AttributionStyleBuilder
-
getter/setter pair
Methods
-
applyStyles(
Map< String, dynamic> styles) → void -
inherited
-
copy(
) → MarkdownTableCellViewModel -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override