MutableDocumentComposer class
- Inheritance
-
- Object
- DocumentComposer
- MutableDocumentComposer
- Implemented types
Constructors
- MutableDocumentComposer({DocumentSelection? initialSelection, SuperEditorImeConfiguration? imeConfiguration})
Properties
-
composingRegion
→ ValueListenable<
DocumentRange?> -
The current composing region, which signifies spans of text
that the IME is thinking about changing.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
isInInteractionMode
→ ValueListenable<
bool> -
Whether the editor should allow special user interactions with the
document content, such as clicking to open a link.
no setterinherited
- latestSelectionChange → DocumentSelectionChange?
-
Returns the most recent selection change in the composer.
no setterinherited
- latestSelectionChangeReason → Object?
-
Returns the reason for the most recent selection change in the composer.
no setterinherited
- preferences → ComposerPreferences
-
Returns the composition preferences for this composer.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → DocumentSelection?
-
Returns the current DocumentSelection for a Document.
no setterinherited
-
selectionChanges
→ Stream<
DocumentSelectionChange> -
A stream of document selection changes.
no setterinherited
-
selectionNotifier
→ ValueListenable<
DocumentSelection?> -
Notifies whenever the current DocumentSelection changes.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clearSelection(
) → void - Clears the current selection.
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onTransactionEnd(
List< EditEvent> edits) → void -
A transaction that was previously started with onTransactionStart has now ended, this
Editable should notify interested parties of changes.
override
-
onTransactionStart(
) → void -
A Editor transaction just started, this Editable should avoid notifying
any listeners of changes until the transaction ends.
override
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void -
Resets this Editable to its initial state.
override
-
setComposingRegion(
DocumentRange? newComposingRegion) → void -
setIsInteractionMode(
bool newValue) → void -
setSelectionWithReason(
DocumentSelection? newSelection, [Object reason = SelectionReason.userInteraction]) → void - Sets the current selection for a Document.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited