ParagraphComponentViewModel class
- Inheritance
-
- Object
- SingleColumnLayoutComponentViewModel
- ParagraphComponentViewModel
- Mixed-in types
Constructors
-
ParagraphComponentViewModel({required String nodeId, DateTime? createdAt, double? maxWidth, EdgeInsetsGeometry padding = EdgeInsets.zero, double opacity = 1.0, Attribution? blockType, int indent = 0, TextBlockIndentCalculator indentCalculator = defaultParagraphIndentCalculator, required AttributedText text, required AttributionStyleBuilder textStyleBuilder, InlineWidgetBuilderChain inlineWidgetBuilders = const [], TextDirection textDirection = TextDirection.ltr, TextAlign textAlignment = TextAlign.left, TextScaler? textScaler, TextSelection? selection, required Color selectionColor, bool highlightWhenEmpty = false, Set<
CustomUnderline> customUnderlines = const <CustomUnderline>{}, TextRange? composingRegion, bool showComposingRegionUnderline = false, UnderlineStyle spellingErrorUnderlineStyle = const SquiggleUnderlineStyle(color: Colors.red), List<TextRange> spellingErrors = const <TextRange>[], UnderlineStyle grammarErrorUnderlineStyle = const SquiggleUnderlineStyle(color: Colors.blue), List<TextRange> grammarErrors = const <TextRange>[]})
Properties
- blockType ↔ Attribution?
-
getter/setter pair
- composingRegion ↔ TextRange?
-
The span of text that's currently sitting in the IME's composing region,
which is underlined by this component.
getter/setter pairinherited
- composingRegionUnderlineStyle ↔ UnderlineStyle
-
getter/setter pairinherited
- createdAt ↔ DateTime?
-
When view model's corresponding node was created, which can be used for
making decisions about animated invalidations.
getter/setter pairinherited
-
customUnderlines
↔ Set<
CustomUnderline> -
getter/setter pairinherited
- customUnderlineStyles ↔ CustomUnderlineStyles?
-
getter/setter pairinherited
-
grammarErrors
↔ List<
TextRange> -
getter/setter pairinherited
- grammarErrorUnderlineStyle ↔ UnderlineStyle
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- highlightWhenEmpty ↔ bool
-
getter/setter pairoverride
- indent ↔ int
-
getter/setter pair
- indentCalculator ↔ TextBlockIndentCalculator
-
getter/setter pair
- inlineWidgetBuilders ↔ InlineWidgetBuilderChain
-
getter/setter pairoverride
- maxWidth ↔ double?
-
The maximum width of this component in the layout, or
nullto defer to the layout's preference.getter/setter pairinherited - nodeId → String
-
finalinherited
- opacity ↔ double
-
The opacity of this whole node.
getter/setter pairinherited
- padding ↔ EdgeInsetsGeometry
-
The padding applied around this component.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection ↔ TextSelection?
-
getter/setter pairoverride
- selectionColor ↔ Color
-
getter/setter pairoverride
- showComposingRegionUnderline ↔ bool
-
Whether to underline the composingRegion.
getter/setter pairinherited
-
spellingErrors
↔ List<
TextRange> -
getter/setter pairinherited
- spellingErrorUnderlineStyle ↔ UnderlineStyle
-
getter/setter pairinherited
- text ↔ AttributedText
-
getter/setter pairoverride
- textAlignment ↔ TextAlign
-
getter/setter pairoverride
- textDirection ↔ TextDirection
-
getter/setter pairoverride
- textScaler ↔ TextScaler?
-
The text scaling policy.
getter/setter pair
- textStyleBuilder ↔ AttributionStyleBuilder
-
getter/setter pairoverride
- textViewModelHashCode → int
-
no setterinherited
Methods
-
applyStyles(
Map< String, dynamic> styles) → void -
inherited
-
copy(
) → ParagraphComponentViewModel -
override
-
createUnderlines(
) → List< Underlines> -
inherited
-
internalCopy(
covariant ParagraphComponentViewModel viewModel) → ParagraphComponentViewModel -
Given a
subclassInstanceof TextComponentViewModel, copies all base-level text properties from this TextComponentViewModel into the givensubclassInstance.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
textViewModelEquals(
Object other) → bool -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override