SingleColumnDocumentComponentContext class
Information that is provided to a ComponentBuilder to construct an appropriate DocumentComponent widget.
Constructors
-
SingleColumnDocumentComponentContext({required BuildContext context, required GlobalKey<
State< componentKey})StatefulWidget> > -
Creates a component context.
const
Properties
-
componentKey
→ GlobalKey<
State< StatefulWidget> > -
A GlobalKey that must be assigned to the DocumentComponent
widget returned by a ComponentBuilder.
final
- context → BuildContext
-
The BuildContext for the parent of the DocumentComponent
that needs to be built.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited