SpellingAndGrammarStyler class
A SingleColumnLayoutStylePhase that applies spelling and grammar error underlines to TextNodes in the document that have reported errors.
Provide a spellingErrorUnderlineStyle and/or grammarErrorUnderlineStyle to override all other style preferences for spelling and grammar error underline styles across all text components.
- Inheritance
-
- Object
- SingleColumnLayoutStylePhase
- SpellingAndGrammarStyler
Constructors
- SpellingAndGrammarStyler({UnderlineStyle? spellingErrorUnderlineStyle, UnderlineStyle? grammarErrorUnderlineStyle, Color? selectionHighlightColor})
Properties
- dirtyCallback ← VoidCallback?
-
no getterinherited
- grammarErrorUnderlineStyle ← UnderlineStyle?
-
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionHighlightColor → Color?
-
The color to use for the selection highlight overrideSelectionColor is called.
final
- spellingErrorUnderlineStyle ← UnderlineStyle?
-
no getter
Methods
-
addErrors(
String nodeId, Set< TextError> errors) → void -
clearAllErrors(
) → void -
clearErrorsForNode(
String nodeId) → void -
clearSomeErrorsForNode(
String nodeId, Set< TextError> errors) → void -
dispose(
) → void -
inherited
-
getErrorsForNode(
String nodeId) → Set< TextError> -
markDirty(
) → void -
Marks this phase as needing to re-run its view model calculations.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overrideSelectionColor(
) → void - Configure this styler to override the default selection color with selectionHighlightColor.
-
style(
Document document, SingleColumnLayoutViewModel viewModel) → SingleColumnLayoutViewModel -
Styles a SingleColumnLayoutViewModel by adjusting the given viewModel.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
useDefaultSelectionColor(
) → void - Stop overriding the default selection color.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited