StraightUnderlineStyle class
- Implemented types
Constructors
- StraightUnderlineStyle({Color color = const Color(0xFF000000), double thickness = 2, StrokeCap capType = StrokeCap.square, double offset = 0})
-
const
Properties
- capType → StrokeCap
-
final
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → double
-
Vertical offset of the underline (positive or negative) from the bottom
edge of the text line's bounding box.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → double
-
final
Methods
-
createPainter(
List< LineSegment> underlines) → CustomPainter -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited