documentOverlayBuilders property
Layers that are displayed on top of the document layout, aligned with the location and size of the document layout.
Implementation
final List<SuperReaderDocumentLayerBuilder> documentOverlayBuilders;
Layers that are displayed on top of the document layout, aligned with the location and size of the document layout.
final List<SuperReaderDocumentLayerBuilder> documentOverlayBuilders;