SuperTextFieldTapHandler class abstract
Tap handler that can (optionally) respond to single, double, and triple taps, as well as dictate the cursor appearance on desktop.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
mouseCursorForContentHover(
SuperTextFieldGestureDetails details) → MouseCursor? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDoubleTapCancel(
) → TapHandlingInstruction -
onDoubleTapDown(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onDoubleTapUp(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onSecondaryTapCancel(
) → TapHandlingInstruction -
onSecondaryTapDown(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onSecondaryTapUp(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onTapCancel(
) → TapHandlingInstruction -
onTapDown(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onTapUp(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onTripleTapCancel(
) → TapHandlingInstruction -
onTripleTapDown(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
onTripleTapUp(
SuperTextFieldGestureDetails details) → TapHandlingInstruction -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited