lineHeight property
The height of a single line of text in this text scroll view, used with minLines and maxLines to size the text field.
If a lineHeight is provided, the TextScrollView is sized as a multiple of that lineHeight. If no lineHeight is provided, the TextScrollView is sized as a multiple of the line-height of the first line of text.
Implementation
final double? lineHeight;